==> kubernetes-model-apiextensions-5.11.2-sources.jar: io/fabric8/kubernetes/api/model/apiextensions/v1/CustomResourceSubresourcesFluentImpl.java <==
package io.fabric8.kubernetes.api.model.apiextensions.v1;

import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public class CustomResourceSubresourcesFluentImpl<A extends io.fabric8.kubernetes.api.model.apiextensions.v1.CustomResourceSubresourcesFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements io.fabric8.kubernetes.api.model.apiextensions.v1.CustomResourceSubresourcesFluent<A>{
  public CustomResourceSubresourcesFluentImpl() {
  }
  public CustomResourceSubresourcesFluentImpl(io.fabric8.kubernetes.api.model.apiextensions.v1.CustomResourceSubresources instance) {
    this.withScale(instance.getScale()); 
    this.withStatus(instance.getStatus()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

  }
  private io.fabric8.kubernetes.api.model.apiextensions.v1.CustomResourceSubresourceScaleBuilder scale;
  private io.fabric8.kubernetes.api.model.apiextensions.v1.CustomResourceSubresourceStatusBuilder status;
  private java.util.Map<java.lang.String,java.lang.Object> additionalProperties;
  
  /**
   * This method has been deprecated, please use method buildScale instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.kubernetes.api.model.apiextensions.v1.CustomResourceSubresourceScale getScale() {
    return this.scale!=null?this.scale.build():null;
  }
  public io.fabric8.kubernetes.api.model.apiextensions.v1.CustomResourceSubresourceScale buildScale() {
    return this.scale!=null?this.scale.build():null;
  }
  public A withScale(io.fabric8.kubernetes.api.model.apiextensions.v1.CustomResourceSubresourceScale scale) {
    _visitables.get("scale").remove(this.scale);
    if (scale!=null){ this.scale= new io.fabric8.kubernetes.api.model.apiextensions.v1.CustomResourceSubresourceScaleBuilder(scale); _visitables.get("scale").add(this.scale);} return (A) this;
  }
  public java.lang.Boolean hasScale() {
    return this.scale != null;
  }
  public A withNewScale(java.lang.String labelSelectorPath,java.lang.String specReplicasPath,java.lang.String statusReplicasPath) {
    return (A)withScale(new CustomResourceSubresourceScale(labelSelectorPath, specReplicasPath, statusReplicasPath));
  }
  public io.fabric8.kubernetes.api.model.apiextensions.v1.CustomResourceSubresourcesFluent.ScaleNested<A> withNewScale() {
    return new io.fabric8.kubernetes.api.model.apiextensions.v1.CustomResourceSubresourcesFluentImpl.ScaleNestedImpl();
  }
  public io.fabric8.kubernetes.api.model.apiextensions.v1.CustomResourceSubresourcesFluent.ScaleNested<A> withNewScaleLike(io.fabric8.kubernetes.api.model.apiextensions.v1.CustomResourceSubresourceScale item) {
    return new io.fabric8.kubernetes.api.model.apiextensions.v1.CustomResourceSubresourcesFluentImpl.ScaleNestedImpl(item);
  }
  public io.fabric8.kubernetes.api.model.apiextensions.v1.CustomResourceSubresourcesFluent.ScaleNested<A> editScale() {
    return withNewScaleLike(getScale());
  }
  public io.fabric8.kubernetes.api.model.apiextensions.v1.CustomResourceSubresourcesFluent.ScaleNested<A> editOrNewScale() {
    return withNewScaleLike(getScale() != null ? getScale(): new io.fabric8.kubernetes.api.model.apiextensions.v1.CustomResourceSubresourceScaleBuilder().build());
  }
  public io.fabric8.kubernetes.api.model.apiextensions.v1.CustomResourceSubresourcesFluent.ScaleNested<A> editOrNewScaleLike(io.fabric8.kubernetes.api.model.apiextensions.v1.CustomResourceSubresourceScale item) {
    return withNewScaleLike(getScale() != null ? getScale(): item);
  }
  
  /**
   * This method has been deprecated, please use method buildStatus instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.kubernetes.api.model.apiextensions.v1.CustomResourceSubresourceStatus getStatus() {
    return this.status!=null?this.status.build():null;
  }
  public io.fabric8.kubernetes.api.model.apiextensions.v1.CustomResourceSubresourceStatus buildStatus() {
    return this.status!=null?this.status.build():null;
  }
  public A withStatus(io.fabric8.kubernetes.api.model.apiextensions.v1.CustomResourceSubresourceStatus status) {
    _visitables.get("status").remove(this.status);
    if (status!=null){ this.status= new io.fabric8.kubernetes.api.model.apiextensions.v1.CustomResourceSubresourceStatusBuilder(status); _visitables.get("status").add(this.status);} return (A) this;
  }
  public java.lang.Boolean hasStatus() {
    return this.status != null;
  }
  public io.fabric8.kubernetes.api.model.apiextensions.v1.CustomResourceSubresourcesFluent.StatusNested<A> withNewStatus() {
    return new io.fabric8.kubernetes.api.model.apiextensions.v1.CustomResourceSubresourcesFluentImpl.StatusNestedImpl();
  }
  public io.fabric8.kubernetes.api.model.apiextensions.v1.CustomResourceSubresourcesFluent.StatusNested<A> withNewStatusLike(io.fabric8.kubernetes.api.model.apiextensions.v1.CustomResourceSubresourceStatus item) {
    return new io.fabric8.kubernetes.api.model.apiextensions.v1.CustomResourceSubresourcesFluentImpl.StatusNestedImpl(item);
  }
  public io.fabric8.kubernetes.api.model.apiextensions.v1.CustomResourceSubresourcesFluent.StatusNested<A> editStatus() {
    return withNewStatusLike(getStatus());
  }
  public io.fabric8.kubernetes.api.model.apiextensions.v1.CustomResourceSubresourcesFluent.StatusNested<A> editOrNewStatus() {
    return withNewStatusLike(getStatus() != null ? getStatus(): new io.fabric8.kubernetes.api.model.apiextensions.v1.CustomResourceSubresourceStatusBuilder().build());
  }
  public io.fabric8.kubernetes.api.model.apiextensions.v1.CustomResourceSubresourcesFluent.StatusNested<A> editOrNewStatusLike(io.fabric8.kubernetes.api.model.apiextensions.v1.CustomResourceSubresourceStatus item) {
    return withNewStatusLike(getStatus() != null ? getStatus(): item);
  }
  public A addToAdditionalProperties(java.lang.String key,java.lang.Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.lang.String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public java.util.Map<java.lang.String,java.lang.Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(additionalProperties);} return (A) this;
  }
  public java.lang.Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    CustomResourceSubresourcesFluentImpl that = (CustomResourceSubresourcesFluentImpl) o;
    if (scale != null ? !scale.equals(that.scale) :that.scale != null) return false;
    if (status != null ? !status.equals(that.status) :that.status != null) return false;
    if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(scale,  status,  additionalProperties,  super.hashCode());
  }
  public class ScaleNestedImpl<N> extends io.fabric8.kubernetes.api.model.apiextensions.v1.CustomResourceSubresourceScaleFluentImpl<io.fabric8.kubernetes.api.model.apiextensions.v1.CustomResourceSubresourcesFluent.ScaleNested<N>> implements io.fabric8.kubernetes.api.model.apiextensions.v1.CustomResourceSubresourcesFluent.ScaleNested<N>,io.fabric8.kubernetes.api.builder.Nested<N>{
    ScaleNestedImpl(io.fabric8.kubernetes.api.model.apiextensions.v1.CustomResourceSubresourceScale item) {
      this.builder = new io.fabric8.kubernetes.api.model.apiextensions.v1.CustomResourceSubresourceScaleBuilder(this, item);
    }
    ScaleNestedImpl() {
      this.builder = new io.fabric8.kubernetes.api.model.apiextensions.v1.CustomResourceSubresourceScaleBuilder(this);
    }
    io.fabric8.kubernetes.api.model.apiextensions.v1.CustomResourceSubresourceScaleBuilder builder;
    public N and() {
      return (N) CustomResourceSubresourcesFluentImpl.this.withScale(builder.build());
    }
    public N endScale() {
      return and();
    }
    
  }
  public class StatusNestedImpl<N> extends io.fabric8.kubernetes.api.model.apiextensions.v1.CustomResourceSubresourceStatusFluentImpl<io.fabric8.kubernetes.api.model.apiextensions.v1.CustomResourceSubresourcesFluent.StatusNested<N>> implements io.fabric8.kubernetes.api.model.apiextensions.v1.CustomResourceSubresourcesFluent.StatusNested<N>,io.fabric8.kubernetes.api.builder.Nested<N>{
    StatusNestedImpl(io.fabric8.kubernetes.api.model.apiextensions.v1.CustomResourceSubresourceStatus item) {
      this.builder = new io.fabric8.kubernetes.api.model.apiextensions.v1.CustomResourceSubresourceStatusBuilder(this, item);
    }
    StatusNestedImpl() {
      this.builder = new io.fabric8.kubernetes.api.model.apiextensions.v1.CustomResourceSubresourceStatusBuilder(this);
    }
    io.fabric8.kubernetes.api.model.apiextensions.v1.CustomResourceSubresourceStatusBuilder builder;
    public N and() {
      return (N) CustomResourceSubresourcesFluentImpl.this.withStatus(builder.build());
    }
    public N endStatus() {
      return and();
    }
    
  }
  
}

==> kubernetes-model-apiextensions-5.12.4-sources.jar: io/fabric8/kubernetes/api/model/apiextensions/v1/CustomResourceSubresourcesFluentImpl.java <==
package io.fabric8.kubernetes.api.model.apiextensions.v1;

import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public class CustomResourceSubresourcesFluentImpl<A extends io.fabric8.kubernetes.api.model.apiextensions.v1.CustomResourceSubresourcesFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements io.fabric8.kubernetes.api.model.apiextensions.v1.CustomResourceSubresourcesFluent<A>{
  public CustomResourceSubresourcesFluentImpl() {
  }
  public CustomResourceSubresourcesFluentImpl(io.fabric8.kubernetes.api.model.apiextensions.v1.CustomResourceSubresources instance) {
    this.withScale(instance.getScale()); 
    this.withStatus(instance.getStatus()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

  }
  private io.fabric8.kubernetes.api.model.apiextensions.v1.CustomResourceSubresourceScaleBuilder scale;
  private io.fabric8.kubernetes.api.model.apiextensions.v1.CustomResourceSubresourceStatusBuilder status;
  private java.util.Map<java.lang.String,java.lang.Object> additionalProperties;
  
  /**
   * This method has been deprecated, please use method buildScale instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.kubernetes.api.model.apiextensions.v1.CustomResourceSubresourceScale getScale() {
    return this.scale!=null?this.scale.build():null;
  }
  public io.fabric8.kubernetes.api.model.apiextensions.v1.CustomResourceSubresourceScale buildScale() {
    return this.scale!=null?this.scale.build():null;
  }
  public A withScale(io.fabric8.kubernetes.api.model.apiextensions.v1.CustomResourceSubresourceScale scale) {
    _visitables.get("scale").remove(this.scale);
    if (scale!=null){ this.scale= new io.fabric8.kubernetes.api.model.apiextensions.v1.CustomResourceSubresourceScaleBuilder(scale); _visitables.get("scale").add(this.scale);} return (A) this;
  }
  public java.lang.Boolean hasScale() {
    return this.scale != null;
  }
  public A withNewScale(java.lang.String labelSelectorPath,java.lang.String specReplicasPath,java.lang.String statusReplicasPath) {
    return (A)withScale(new CustomResourceSubresourceScale(labelSelectorPath, specReplicasPath, statusReplicasPath));
  }
  public io.fabric8.kubernetes.api.model.apiextensions.v1.CustomResourceSubresourcesFluent.ScaleNested<A> withNewScale() {
    return new io.fabric8.kubernetes.api.model.apiextensions.v1.CustomResourceSubresourcesFluentImpl.ScaleNestedImpl();
  }
  public io.fabric8.kubernetes.api.model.apiextensions.v1.CustomResourceSubresourcesFluent.ScaleNested<A> withNewScaleLike(io.fabric8.kubernetes.api.model.apiextensions.v1.CustomResourceSubresourceScale item) {
    return new io.fabric8.kubernetes.api.model.apiextensions.v1.CustomResourceSubresourcesFluentImpl.ScaleNestedImpl(item);
  }
  public io.fabric8.kubernetes.api.model.apiextensions.v1.CustomResourceSubresourcesFluent.ScaleNested<A> editScale() {
    return withNewScaleLike(getScale());
  }
  public io.fabric8.kubernetes.api.model.apiextensions.v1.CustomResourceSubresourcesFluent.ScaleNested<A> editOrNewScale() {
    return withNewScaleLike(getScale() != null ? getScale(): new io.fabric8.kubernetes.api.model.apiextensions.v1.CustomResourceSubresourceScaleBuilder().build());
  }
  public io.fabric8.kubernetes.api.model.apiextensions.v1.CustomResourceSubresourcesFluent.ScaleNested<A> editOrNewScaleLike(io.fabric8.kubernetes.api.model.apiextensions.v1.CustomResourceSubresourceScale item) {
    return withNewScaleLike(getScale() != null ? getScale(): item);
  }
  
  /**
   * This method has been deprecated, please use method buildStatus instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.kubernetes.api.model.apiextensions.v1.CustomResourceSubresourceStatus getStatus() {
    return this.status!=null?this.status.build():null;
  }
  public io.fabric8.kubernetes.api.model.apiextensions.v1.CustomResourceSubresourceStatus buildStatus() {
    return this.status!=null?this.status.build():null;
  }
  public A withStatus(io.fabric8.kubernetes.api.model.apiextensions.v1.CustomResourceSubresourceStatus status) {
    _visitables.get("status").remove(this.status);
    if (status!=null){ this.status= new io.fabric8.kubernetes.api.model.apiextensions.v1.CustomResourceSubresourceStatusBuilder(status); _visitables.get("status").add(this.status);} return (A) this;
  }
  public java.lang.Boolean hasStatus() {
    return this.status != null;
  }
  public io.fabric8.kubernetes.api.model.apiextensions.v1.CustomResourceSubresourcesFluent.StatusNested<A> withNewStatus() {
    return new io.fabric8.kubernetes.api.model.apiextensions.v1.CustomResourceSubresourcesFluentImpl.StatusNestedImpl();
  }
  public io.fabric8.kubernetes.api.model.apiextensions.v1.CustomResourceSubresourcesFluent.StatusNested<A> withNewStatusLike(io.fabric8.kubernetes.api.model.apiextensions.v1.CustomResourceSubresourceStatus item) {
    return new io.fabric8.kubernetes.api.model.apiextensions.v1.CustomResourceSubresourcesFluentImpl.StatusNestedImpl(item);
  }
  public io.fabric8.kubernetes.api.model.apiextensions.v1.CustomResourceSubresourcesFluent.StatusNested<A> editStatus() {
    return withNewStatusLike(getStatus());
  }
  public io.fabric8.kubernetes.api.model.apiextensions.v1.CustomResourceSubresourcesFluent.StatusNested<A> editOrNewStatus() {
    return withNewStatusLike(getStatus() != null ? getStatus(): new io.fabric8.kubernetes.api.model.apiextensions.v1.CustomResourceSubresourceStatusBuilder().build());
  }
  public io.fabric8.kubernetes.api.model.apiextensions.v1.CustomResourceSubresourcesFluent.StatusNested<A> editOrNewStatusLike(io.fabric8.kubernetes.api.model.apiextensions.v1.CustomResourceSubresourceStatus item) {
    return withNewStatusLike(getStatus() != null ? getStatus(): item);
  }
  public A addToAdditionalProperties(java.lang.String key,java.lang.Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new java.util.LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new java.util.LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.lang.String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public java.util.Map<java.lang.String,java.lang.Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new java.util.LinkedHashMap(additionalProperties);} return (A) this;
  }
  public java.lang.Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    CustomResourceSubresourcesFluentImpl that = (CustomResourceSubresourcesFluentImpl) o;
    if (scale != null ? !scale.equals(that.scale) :that.scale != null) return false;
    if (status != null ? !status.equals(that.status) :that.status != null) return false;
    if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(scale,  status,  additionalProperties,  super.hashCode());
  }
  public class ScaleNestedImpl<N> extends io.fabric8.kubernetes.api.model.apiextensions.v1.CustomResourceSubresourceScaleFluentImpl<io.fabric8.kubernetes.api.model.apiextensions.v1.CustomResourceSubresourcesFluent.ScaleNested<N>> implements io.fabric8.kubernetes.api.model.apiextensions.v1.CustomResourceSubresourcesFluent.ScaleNested<N>,io.fabric8.kubernetes.api.builder.Nested<N>{
    ScaleNestedImpl(io.fabric8.kubernetes.api.model.apiextensions.v1.CustomResourceSubresourceScale item) {
      this.builder = new io.fabric8.kubernetes.api.model.apiextensions.v1.CustomResourceSubresourceScaleBuilder(this, item);
    }
    ScaleNestedImpl() {
      this.builder = new io.fabric8.kubernetes.api.model.apiextensions.v1.CustomResourceSubresourceScaleBuilder(this);
    }
    io.fabric8.kubernetes.api.model.apiextensions.v1.CustomResourceSubresourceScaleBuilder builder;
    public N and() {
      return (N) CustomResourceSubresourcesFluentImpl.this.withScale(builder.build());
    }
    public N endScale() {
      return and();
    }
    
  }
  public class StatusNestedImpl<N> extends io.fabric8.kubernetes.api.model.apiextensions.v1.CustomResourceSubresourceStatusFluentImpl<io.fabric8.kubernetes.api.model.apiextensions.v1.CustomResourceSubresourcesFluent.StatusNested<N>> implements io.fabric8.kubernetes.api.model.apiextensions.v1.CustomResourceSubresourcesFluent.StatusNested<N>,io.fabric8.kubernetes.api.builder.Nested<N>{
    StatusNestedImpl(io.fabric8.kubernetes.api.model.apiextensions.v1.CustomResourceSubresourceStatus item) {
      this.builder = new io.fabric8.kubernetes.api.model.apiextensions.v1.CustomResourceSubresourceStatusBuilder(this, item);
    }
    StatusNestedImpl() {
      this.builder = new io.fabric8.kubernetes.api.model.apiextensions.v1.CustomResourceSubresourceStatusBuilder(this);
    }
    io.fabric8.kubernetes.api.model.apiextensions.v1.CustomResourceSubresourceStatusBuilder builder;
    public N and() {
      return (N) CustomResourceSubresourcesFluentImpl.this.withStatus(builder.build());
    }
    public N endStatus() {
      return and();
    }
    
  }
  
}
